|Build Status| |Coverage Status| |PyPI Version|

BrownAnt
========

BrownAnt is a crawling framework.


Installation
------------

::

    $ pip install brownant


Links
-----

- `Document <https://brownant.readthedocs.org>`_
- `Issue Track <https://github.com/tonyseek/brownant/issues>`_


Issues
------

If you want to report bugs or request features, please create issues on
`GitHub Issues <https://github.com/tonyseek/brownant/issues>`_.


Contributes
-----------

You can send a pull reueqst on
`GitHub <https://github.com/tonyseek/brownant/pulls>`_.


.. |Build Status| image:: https://travis-ci.org/tonyseek/brownant.png?branch=master,develop
   :target: https://travis-ci.org/tonyseek/brownant
.. |Coverage Status| image:: https://coveralls.io/repos/tonyseek/brownant/badge.png?branch=develop
   :target: https://coveralls.io/r/tonyseek/brownant
.. |PyPI Version| image:: https://pypip.in/v/brownant/badge.png
   :target: https://pypi.python.org/pypi/brownant
